package binarization.data;

/**
 * Histograma acumulado normalizado de ordem dada.
 *
 * @author denis
 * @see IGrayLevelImage
 * @see IHistogram
 * @see INormalizedHistogram
 */
public interface IAccumulatedHistogram {

	/**
	 * Devolve o valor acumulado normalizado da intensidade dada.
	 * 
	 * <p>As intensidades sao definidas de 0 a {@link #maxIntensity}, inclusivo</p>
	 * 
	 * @param intensity a intensidade da qual se quer o valor acumulado
	 * @return o valor acumulado normalizado da intensidade dada
	 * @throws IndexOutOfBoundsException se a intensidade estiver fora da faixa
	 *   {@code [0, maxIntensity]}
	 */
	double valueAt(int intensity);

	/**
	 * Devolve a intensidade maxima representada por este histograma. Note que
	 * a minima e sempre zero.
	 * 
	 * @return a intensidade maxima representada por este histograma
	 */
	int maxIntensity();

	/**
	 * Devolve a ordem do histograma acumulado, i.e., o expoente {@code x}
	 * ao qual e elevado a intensidade no termo {@code i^x * probabilidade},
	 * para toda intensidade {@code i}. Este expoente e um inteiro nao negativo.
	 * 
	 * @return a ordem do histograma acumulado
	 */
	int order();
}
