package binarization.data;

/**
 * Interface que define uma imagem binaria.
 *
 * @author denis
 * @see IImage
 * @see IGrayLevelImage
 * @see Images
 * @see AbstractBinaryImage
 * @see Pixel
 * @see ImageSize
 */
public interface IBinaryImage extends IImage {

	@Override
	boolean isEmpty();

	@Override
	ImageSize size();

	@Override
	Pixel pixelAt(ImagePoint p);

	@Override
	Pixel pixelAtUnchecked(int x, int y);

	@Override
	IBinaryImage windowOf(ImagePoint center, ImageSize size);

	/**
	 * Devolve o complemento desta imagem. Em outras palavras, o fundo e os
	 * objetos trocam de cor.
	 * 
	 * @return o complemento desta imagem
	 */
	IBinaryImage complement();

	/**
	 * Construtor de uma imagem binaria. Cada pixel da imagem e ligado um a um,
	 * por fim construindo a imagem binaria imutavel.
	 */
	interface Builder {

		/**
		 * Diferencia este ponto do fundo. O fundo devera ser {@link Pixel#ofWhite}
		 * 
		 * @param p o ponto do pixel
		 * @throws IndexOutOfBoundsException se o ponto estiver fora da imagem
		 */
		void setPixel(ImagePoint p);

		/**
		 * Diferencia este ponto (x, y) do fundo. O fundo devera ser {@link Pixel#ofWhite}.
		 * Nao checa se o ponto dado esta na imagem.
		 * 
		 * @param x a coordenada horizontal do pixel
		 * @param y a coordenada vertical do pixel
		 */
		void setPixelUnchecked(int x, int y);

		/**
		 * Constroi a imagem binaria com os pixels ligados como objeto e o restante
		 * como fundo.
		 * 
		 * @return a imagem binaria crrespondente a este construtor
		 */
		IBinaryImage build();
	}
}
