package binarization.data;

/**
 * Histograma de frequencia das intensidades de uma imagem.
 *
 * @author denis
 * @see IGrayLevelImage
 * @see INormalizedHistogram
 * @see IAccumulatedHistogram
 */
public interface IHistogram {

	/**
	 * Devolve o numero de ocorrencias da intensidade dada numa imagem.
	 * 
	 * <p>As intensidades sao definidas de 0 a {@link #maxIntensity}, inclusivo</p>
	 * 
	 * @param intensity a intensidade da qual se quer a frequencia
	 * @return o numero de ocorrencias da intensidade dada numa imagem
	 * @throws IndexOutOfBoundsException se a intensidade estiver fora da faixa
	 *   {@code [0, maxIntensity]}
	 */
	long frequencyAt(int intensity);

	/**
	 * Devolve a intensidade maxima representada por este histograma. Note que
	 * a minima e sempre zero.
	 * 
	 * @return a intensidade maxima representada por este histograma
	 */
	int maxIntensity();

	/**
	 * Devolve o histograma normalizado deste histograma, i.e., o histograma
	 * das probabilidades de cada intensidade.
	 * 
	 * @return o histograma normalizado deste histograma
	 */
	INormalizedHistogram normalize();
}
