package binarization.data;

/**
 * Histograma normalizado de uma imagem.
 *
 * @author denis
 * @see IGrayLevelImage
 * @see IHistogram
 * @see IAccumulatedHistogram
 */
public interface INormalizedHistogram {

	/**
	 * Devolve a probabilidade da intensidade dada.
	 * 
	 * <p>As intensidades sao definidas de 0 a {@link #maxIntensity}, inclusivo</p>
	 * 
	 * @param intensity a intensidade da qual se quer a probabilidade
	 * @return a probabilidade da intensidade dada
	 * @throws IndexOutOfBoundsException se a intensidade estiver fora da faixa
	 *   {@code [0, maxIntensity]
	 */
	double probabilityAt(int intensity);

	/**
	 * Devolve a intensidade maxima representada por este histograma. Note que
	 * a minima e sempre zero.
	 * 
	 * @return a intensidade maxima representada por este histograma
	 */
	int maxIntensity();

	/**
	 * Devolve o histograma acumulado de ordem dada deste histograma normalizado.
	 * A ordem e o expoente ao qual e elevado a intensidade em cada termo da soma.
	 * Note que se o expoente for zero, e simplesmente a probabilidade acumulada.
	 * 
	 * @param order a ordem do histograma acumulado
	 * @return o histograma acumulado de ordem dada
	 */
	IAccumulatedHistogram accumulate(int order);
}
