package binarization.data;

/**
 * Implementacao padrao simples de uma imagem binaria.
 *
 * <p>Imutavel, e nao pode ser herdada fora do pacote para garantir sua
 * imutabilidade.</p>
 *
 * @author denis
 */
class SimpleBinaryImage extends AbstractBinaryImage implements IBinaryImage {

	private final Pixel[][] pixels;
	private final ImageSize size;

	/**
	 * <p>Constroi uma imagem binaria a partir de uma matriz com valores dos
	 * pixels.</p>
	 * 
	 * <p>Esta implementacao assume que a matriz nao sera modificada, portanto
	 * nao faz copias defensivas.</p>
	 *
	 * @param pixels a matriz que define a imagem
	 */
	SimpleBinaryImage(Pixel[][] pixels) {
		this.pixels = pixels;
		this.size = ImageSize.of(pixels.length, pixels[0].length);
	}

	@Override
	public ImageSize size() {
		return size;
	}

	@Override
	public Pixel pixelAtUnchecked(int x, int y) {
		return pixels[x][y];
	}
}
