package binarization.data;

/**
 * Implementacao padrao simples de uma imagem em niveis de cinza.
 * 
 * <p>Imutavel, e nao pode ser herdada fora do pacote para garantir sua
 * imutabilidade.</p>
 *
 * @author denis
 */
class SimpleGrayLevelImage extends AbstractGrayLevelImage implements IGrayLevelImage {

	private final Pixel[][] pixels;
	private final ImageSize size;

	/**
	 * <p>Constroi uma imagem em niveis de cinza a partir de uma matriz com
	 * valores dos pixels.</p>
	 * 
	 * <p>Esta implementacao assume que a matriz nao sera modificada, portanto
	 * nao faz copias defensivas.</p>
	 *
	 * @param pixels a matriz que define a imagem
	 */
	SimpleGrayLevelImage(Pixel[][] pixels) {
		this.pixels = pixels;
		this.size = ImageSize.of(pixels.length, pixels[0].length);
	}

	@Override
	public ImageSize size() {
		return size;
	}

	@Override
	public Pixel pixelAt(ImagePoint p) {
		if (!p.isInside(size)) {
			throw new IndexOutOfBoundsException("Point p:" + p + " is not inside this image.");
		}
		return pixels[p.x()][p.y()];
	}

	@Override
	public Pixel pixelAtUnchecked(int x, int y) {
		return pixels[x][y];
	}
}
