package binarization.data;

/**
 * Implementacao simples de um histograma de frequencias de intensidade
 * de uma imagem.
 * 
 * <p>Imutavel, e nao pode ser herdada fora do pacote para garantir sua
 * imutabilidade.</p>
 * 
 * @author denis
 */
class SimpleHistogram implements IHistogram {

	private final long[] frequencies;

	SimpleHistogram(long[] frequencies) {
		this.frequencies = frequencies;
	}

	@Override
	public long frequencyAt(int intensity) {
		if (intensity < 0 || intensity > maxIntensity()) {
			throw new IndexOutOfBoundsException("Intensity given out of range: [0, " +
					maxIntensity() + "]");
		}
		return frequencies[intensity];
	}

	@Override
	public int maxIntensity() {
		return frequencies.length - 1;
	}

	@Override
	public INormalizedHistogram normalize() {
		long sum = 0;
		for (int i = 0; i < frequencies.length; i++) {
			sum += frequencies[i];
		}

		final double[] probabilities = new double[frequencies.length];
		for (int i = 0; i < frequencies.length; i++) {
			probabilities[i] = (double) frequencies[i] / sum;
		}
		return new SimpleNormalizedHistogram(probabilities);
	}
}
