package binarization.data;

/**
 * Implementacao simples de um histograma normalizado de uma imagem.
 * 
 * <p>Imutavel, e nao pode ser herdada fora do pacote para garantir sua
 * imutabilidade.</p>
 * 
 * @author denis
 */
class SimpleNormalizedHistogram implements INormalizedHistogram {

	private final double[] probabilities;

	SimpleNormalizedHistogram(double[] probabilities) {
		this.probabilities = probabilities;
	}

	@Override
	public double probabilityAt(int intensity) {
		if (intensity < 0 || intensity > maxIntensity()) {
			throw new IndexOutOfBoundsException("Intensity given out of range: [0, "
					+ maxIntensity() + "]");
		}
		return probabilities[intensity];
	}

	@Override
	public int maxIntensity() {
		return probabilities.length - 1;
	}

	@Override
	public IAccumulatedHistogram accumulate(int order) {
		if (order < 0) {
			throw new IllegalArgumentException("Order must be non-negative.");
		}

		final double[] values = new double[probabilities.length];

		values[0] = probabilities[0];
		for (int i = 1; i < probabilities.length; i++) {
			values[i] = values[i - 1] + (Math.pow(i + 1, order) * probabilities[i]);
		}

		return new SimpleAccumulatedHistogram(values, order);
	}
}
