package binarization.data.util;

/**
 * Implementacao simples de duplas imutaveis para Java.
 * 
 * @param <E1> tipo do primeiro elemento do par
 * @param <E2> tipo do segundo elemento do par
 * 
 * @author denis
 */
public class Pair<E1, E2> {

	private final E1 first;
	private final E2 second;

	/**
	 * Devolve um par com os dois elementos dados.
	 * 
	 * @param first o primeiro elemento do par
	 * @param second o segundo elemento do par
	 */
	public static <E1, E2> Pair<E1, E2> of(E1 first, E2 second) {
		return new Pair<E1, E2>(first, second);
	}

	/**
	 * Constroi um par com os dois elementos dados.
	 * 
	 * @param first o primeiro elemento do par
	 * @param second o segundo elemento do par
	 */
	private Pair(E1 first, E2 second) {
		this.first = first;
		this.second = second;
	}

	/**
	 * Devolve o primeiro elemento do par.
	 * 
	 * @return o primeiro elemento do par
	 */
	public E1 first() {
		return first;
	}

	/**
	 * Devolve o segundo elemento do par.
	 * 
	 * @return o segundo elemento do par
	 */
	public E2 second() {
		return second;
	}

	@Override
	public boolean equals(Object o) {
		if (!(o instanceof Pair)) {
			return false;
		}

		final Pair that = (Pair) o;
		if (this.first.equals(that.first) && this.second.equals(that.second)) {
			return true;
		} else {
			return false;
		}
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 71 * hash + (this.first != null ? this.first.hashCode() : 0);
		hash = 71 * hash + (this.second != null ? this.second.hashCode() : 0);
		return hash;
	}
}
