package binarization.examples;

import binarization.IBinarizationMethod;
import binarization.Main;
import binarization.data.IBinaryImage;
import binarization.data.IGrayLevelImage;
import binarization.data.Images;
import java.io.File;
import java.io.IOException;
import java.util.Scanner;

/**
 * Programa que executa os metodos de binarizacao para cada imagem dada no
 * arquivo de entrada. Nao utiliza metricas.
 *
 * @author denis
 */
public class ExampleMethodsOnly {

	private static final String FILE_SEPARATOR = System.getProperty("file.separator");
	private static final String RESULT_DIR = "binarization_results" + FILE_SEPARATOR;

	/**
	 * Garante a nao-instanciabilidade da classe.
	 */
	private ExampleMethodsOnly() {
	}

	/**
	 * Ponto de entrada do programa. Escreve os resultados em {@code RESULT_DIR}.
	 * 
	 * @param args args[0] e o arquivo que contem o nome das imagens a ser binarizadas
	 */
	public static void main(String[] args) {
		if (args.length < 1) {
			System.out.println("Requer um arquivo com as imagens de entrada.");
			System.exit(-1);
		}

		System.out.println("Entrada: " + args[0]);
		System.out.println();

		final Iterable<IBinarizationMethod> methods = Methods.getAllMethods();

		Main.createDirectory(RESULT_DIR);

		Scanner scanner = null;
		try {
			scanner = new Scanner(new File(args[0]));
			while (scanner.hasNext()) {
				final String grayPath = scanner.next();
				final String grayName = Main.extractName(grayPath);
				final IGrayLevelImage image = Images.loadGrayLevelImage(grayPath);
				
				final String directory = RESULT_DIR + grayName + FILE_SEPARATOR;

				for (IBinarizationMethod method : methods) {
					final String path = directory + method.getLabel() + ".png";

					final IBinaryImage result = method.binarize(image);
					Images.saveImage(result, path);

					System.out.println("Criada a imagem " + path);
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(-1);
		} finally {
			if (scanner != null) {
				scanner.close();
			}
		}
	}
}
