package binarization.methods;

import binarization.IBinarizationMethod;
import binarization.data.IBinaryImage;
import binarization.data.IGrayLevelImage;
import binarization.data.Images;
import binarization.data.ImagePoint;

/**
 * Metodo de binarizacao que calcula um limiar para imagem inteira e depois a
 * aplica.
 *
 * @author denis
 * @see IBinarizationMethod
 * @see IBinaryImage
 * @see IGrayLevelImage
 * @see AbstractLocalAdaptiveThresholding
 */
public abstract class AbstractGlobalThresholding implements IBinarizationMethod {

	/**
	 * Devolve o valor do limiar calculado pelo metodo.
	 * 
	 * @param image a imagem em niveis de cinza
	 * @return o limiar calculado pelo metodo
	 */
	public abstract double getThreshold(IGrayLevelImage image);

	@Override
	public abstract String getLabel();

	@Override
	public final IBinaryImage binarize(IGrayLevelImage input) {
		final double threshold = getThreshold(input);

		final IBinaryImage.Builder builder = Images.newBinaryImageBuilder(input.size());

		for (int x = 0; x < input.size().width(); x++) {
			for (int y = 0; y < input.size().height(); y++) {

				final int intensity = input.pixelAtUnchecked(x, y).value();

				if (intensity <= threshold) {
					builder.setPixelUnchecked(x, y);
				}

			}
		}

		return builder.build();
	}
}
