package binarization.methods;

import binarization.IBinarizationMethod;
import binarization.Main;
import binarization.data.IBinaryImage;
import binarization.data.IGrayLevelImage;
import binarization.data.Images;
import java.io.File;
import java.io.IOException;
import java.util.Scanner;

/**
 * Metodo que so carrega resultados de arquivos. Utilizado para simular
 * a execucao de metodos nao implementados.
 *
 * @author denis
 */
public class FileMethod implements IBinarizationMethod {

	private static final String FILE_SEPARATOR = System.getProperty("file.separator");
	private final String filename;
	private final Scanner scanner;

	/**
	 * Constroi um metodo carregador de arquivos. O caminho dado deve conter um
	 * arquivo de texto com os caminhos dos arquivos a ser carregados.
	 * 
	 * @param path o caminho para um arquivo de texto com os caminhos das imagens
	 */
	public FileMethod(String path) {
		this.filename = Main.extractName(path);

		try {
			this.scanner = new Scanner(new File(path));
		} catch (IOException e) {
			throw new IllegalArgumentException("Path '" + path + "' could not be opened.");
		}
	}

	/**
	 * Extrai o nome do arquivo com sufixo do caminho dado.
	 * 
	 * @param path o caminho do arquivo
	 * @return o nome do arquivo com sufixo
	 */
	public static String extractName(String path) {
		final int lastSeparator = path.lastIndexOf(FILE_SEPARATOR) + FILE_SEPARATOR.length();

		return path.substring(lastSeparator);
	}

	@Override
	public IBinaryImage binarize(IGrayLevelImage input) {
		if (scanner.hasNext()) {
			return Images.loadBinaryImage(scanner.next());
		} else {
			return Images.emptyBinaryImage();
		}
	}

	@Override
	public String getLabel() {
		return "file_" + filename;
	}

	@Override
	public String toString() {
		return "File: " + filename;
	}
}
