package binarization.methods;

import binarization.IBinarizationMethod;
import binarization.data.IGrayLevelImage;

/**
 * Metodo de White. (precisa de citacao)
 * 
 * <p>Calcula o limiar para uma janela igual a
 * {@code m(x, y) / bias}, onde:<ol>
 * 
 * <li>{@code bias} é ..., </li>
 * <li>{@code m(x, y)} e a media centrada no pixel {@code (x, y)}.</li>
 * </ol></p>
 * 
 * <p>O valor recomendado para o bias e 2.</p>
 * 
 * <p>A equacao na verdade e um pouco diferente, pois ele nao isola o valor do
 * limiar, mas classifica como 1 se {@code m(x, y) < (x, y) * bias},
 * 0 caso contrario.</p>
 *
 * @author denis
 */
public class WhiteMethod extends AbstractLocalAdaptiveThresholding implements IBinarizationMethod {

	private static final double RECOMMENDED_BIAS = 2.0;
//
	private final double bias;

	public WhiteMethod(int windowSize, double bias) {
		super(windowSize);
		this.bias = bias;
	}

	public WhiteMethod(int windowSize) {
		this(windowSize, RECOMMENDED_BIAS);
	}

	@Override
	public double getThreshold(IGrayLevelImage window) {
		final double mean = window.getMean();

		return mean / bias;
	}

	@Override
	public String getLabel() {
		return "white_window" + getWindowSize() + "_bias" + bias;
	}

	@Override
	public String toString() {
		return "White, Window Size: " + getWindowSize() + ", bias: " + bias;
	}
}
