package binarization.util;

import ij.ImagePlus;
import ij.process.ByteProcessor;
import java.io.File;
import net.sf.ij.jaiio.JAIReader;

/**
 * Classe utilitaria que encapsula a logica de E/S.
 *
 * @author denis
 */
public class ImageIoUtil {

	/**
	 * Garante a nao-instanciabilidade da classe.
	 */
	private ImageIoUtil() {
	}

	/**
	 * Carrega a imagem encontrada no caminho dado e devolve os valores de seus
	 * pixels.
	 * 
	 * @param path o caminho onde se encontra a imagem
	 * @return os valores dos pixels da imagem encontrada no caminho dado
	 */
	public static int[][] loadGrayLevelImageFile(String path) {
		try {
			return JAIReader.read(new File(path))[0].getProcessor().convertToByte(true).getIntArray();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

	/**
	 * Salva os valores dos pixels dados numa imagem de caminho dado.
	 * 
	 * @param pixels os valores dos pixels a serem salvos
	 * @param path o caminho onde serao salva a imagem com os valores dos pixels
	 */
	public static void saveGrayLevelImageFile(int pixels[][], String path) {
		final ByteProcessor image = new ByteProcessor(pixels.length, pixels[0].length);
		image.setIntArray(pixels);

		ij.IJ.save(new ImagePlus("", image), path);
	}
}
